from a10sdk.common.A10BaseClass import A10BaseClass


class Neighbor(A10BaseClass):
    
    """Class Description::
    Specify a neighbor router.

    Class neighbor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param peer_group_neighbor_list: {"minItems": 1, "items": {"type": "peer-group-neighbor"}, "uniqueItems": true, "array": [{"required": ["peer-group"], "properties": {"timers-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "activate": {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "route-refresh": {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}, "ve": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "timers-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "dynamic": {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}, "loopback": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}, "default-originate": {"default": 0, "optional": true, "type": "number", "description": "Originate default route to this neighbor", "format": "flag"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "shutdown": {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "advertisement-interval": {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "lif": {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "update-source-ip": {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}, "collide-established": {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}, "next-hop-self": {"default": 0, "optional": true, "type": "number", "description": "Disable the next hop calculation for this neighbor", "format": "flag"}, "pass-encrypted": {"optional": true, "type": "encrypted", "format": "encrypted"}, "peer-group": {"description": "Neighbor tag", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "dont-capability-negotiate": {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}, "ebgp-multihop-hop-count": {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "pass-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "connection-retry-time": {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "description": {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "peer-group-remote-as": {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "disallow-infinite-holdtime": {"default": 0, "optional": true, "type": "number", "description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "trunk": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "update-source-ipv6": {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}, "maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "peer-group-key": {"default": 0, "optional": true, "type": "number", "description": "Configure peer-group", "format": "flag"}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "as-origination-interval": {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "type": "number", "maximum": 600, "minimum": 1, "optional": true}, "override-capability": {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}, "enforce-multihop": {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}, "strict-capability-match": {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}, "ebgp-multihop": {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}, "ethernet": {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}, "connect": {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/neighbor/peer-group-neighbor/{peer-group}"}
    :param ipv6_neighbor_list: {"minItems": 1, "items": {"type": "ipv6-neighbor"}, "uniqueItems": true, "array": [{"required": ["neighbor-ipv6"], "properties": {"timers-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "activate": {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "route-refresh": {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}, "ve": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "timers-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "bfd-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-type": {"optional": true, "enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': md5; 'meticulous-md5': meticulous-md5; 'meticulous-sha1': meticulous-sha1; 'sha1': sha1; 'simple': simple;  (Keyed MD5/Meticulous Keyed MD5/Meticulous Keyed SHA1/Keyed SHA1/Simple Password)", "format": "enum"}, "dynamic": {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}, "loopback": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}, "multihop": {"default": 0, "optional": true, "type": "number", "description": "Enable multihop", "format": "flag"}, "default-originate": {"description": "Originate default route to this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "shutdown": {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "nbr-remote-as": {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "description": {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}, "advertisement-interval": {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "lif": {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "bfd": {"default": 0, "optional": true, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "collide-established": {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}, "next-hop-self": {"description": "Disable the next hop calculation for this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "pass-encrypted": {"optional": true, "type": "encrypted", "format": "encrypted"}, "dont-capability-negotiate": {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "peer-group-name", "type": "string"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}, "ebgp-multihop-hop-count": {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "pass-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-id": {"description": "Key ID", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}, "connection-retry-time": {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "update-source-ip": {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}, "neighbor-ipv6": {"optional": false, "type": "string", "description": "Neighbor IPv6 address", "format": "ipv6-address"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "bfd-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "disallow-infinite-holdtime": {"description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "trunk": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "update-source-ipv6": {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}, "maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "peer-group-name": {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "not-list": ["advertisement-interval", "as-origination-interval", "default-originate", "disallow-infinite-holdtime", "next-hop-self", "timers", "unsuppress-map"], "optional": true, "maxLength": 128, "type": "string"}, "as-origination-interval": {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "override-capability": {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}, "enforce-multihop": {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}, "strict-capability-match": {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}, "ebgp-multihop": {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}, "ethernet": {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}, "connect": {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/neighbor/ipv6-neighbor/{neighbor-ipv6}"}
    :param ipv4_neighbor_list: {"minItems": 1, "items": {"type": "ipv4-neighbor"}, "uniqueItems": true, "array": [{"required": ["neighbor-ipv4"], "properties": {"timers-holdtime": {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "activate": {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}, "route-refresh": {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}, "ve": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}, "weight": {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "timers-keepalive": {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "bfd-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-type": {"optional": true, "enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': md5; 'meticulous-md5': meticulous-md5; 'meticulous-sha1': meticulous-sha1; 'sha1': sha1; 'simple': simple;  (Keyed MD5/Meticulous Keyed MD5/Meticulous Keyed SHA1/Keyed SHA1/Simple Password)", "format": "enum"}, "dynamic": {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}, "loopback": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}, "multihop": {"default": 0, "optional": true, "type": "number", "description": "Enable multihop", "format": "flag"}, "default-originate": {"description": "Originate default route to this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "distribute-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}, "shutdown": {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}, "prefix-list-direction": {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}, "as-origination-interval": {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "nbr-remote-as": {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "advertisement-interval": {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}, "lif": {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}, "neighbor-route-map-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}, "send-community-val": {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}, "bfd": {"default": 0, "optional": true, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}, "collide-established": {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}, "next-hop-self": {"description": "Disable the next hop calculation for this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "pass-encrypted": {"optional": true, "type": "encrypted", "format": "encrypted"}, "dont-capability-negotiate": {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}, "unsuppress-map": {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "peer-group-name", "type": "string"}, "passive": {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}, "ebgp-multihop-hop-count": {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "allowas-in": {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}, "pass-value": {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "key-id": {"description": "Key ID", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}, "connection-retry-time": {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "update-source-ip": {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}, "description": {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}, "neighbor-ipv4": {"optional": false, "type": "string", "description": "Neighbor address", "format": "ipv4-address"}, "inbound": {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}, "maximum-prefix-thres": {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}, "bfd-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "disallow-infinite-holdtime": {"description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}, "trunk": {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}, "remove-private-as": {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}, "neighbor-filter-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}, "update-source-ipv6": {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}, "maximum-prefix": {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}, "neighbor-prefix-lists": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}, "allowas-in-count": {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}, "peer-group-name": {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "not-list": ["advertisement-interval", "as-origination-interval", "default-originate", "disallow-infinite-holdtime", "next-hop-self", "timers", "unsuppress-map"], "optional": true, "maxLength": 128, "type": "string"}, "enforce-multihop": {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}, "override-capability": {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}, "route-map": {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "strict-capability-match": {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}, "ebgp-multihop": {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}, "ethernet": {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}, "connect": {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/router/bgp/{as-number}/neighbor/ipv4-neighbor/{neighbor-ipv4}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/neighbor`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "neighbor"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/neighbor"
        self.DeviceProxy = ""
        self.peer_group_neighbor_list = []
        self.ipv6_neighbor_list = []
        self.ipv4_neighbor_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Hash_Algorithm: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Protocol: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DH_Group: {"type": "number", "format": "number"}
    :param Peer_IP: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Local_IP: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Anti_Replay: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Lifebytes: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param NAT_Traversal: {"type": "number", "format": "number"}
    :param SA_Index: {"type": "number", "format": "number"}
    :param Remote_SPI: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Mode: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Encryption_Algorithm: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Local_SPI: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Lifetime: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.Hash_Algorithm = ""
        self.Protocol = ""
        self.DH_Group = ""
        self.Peer_IP = ""
        self.Local_IP = ""
        self.Anti_Replay = ""
        self.Lifebytes = ""
        self.NAT_Traversal = ""
        self.SA_Index = ""
        self.Remote_SPI = ""
        self.Mode = ""
        self.Encryption_Algorithm = ""
        self.Local_SPI = ""
        self.Lifetime = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipsec(A10BaseClass):
    
    """Class Description::
    Operational Status for the object ipsec.

    Class ipsec supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "IPsec name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/ipsec/{name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ipsec"
        self.a10_url="/axapi/v3/vpn/ipsec/{name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Remote(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv4_list: {"minLength": 1, "maxLength": 63, "type": "string", "description": "IP-list of IPv4 remote clients (IP-list name)", "format": "string-rlx"}
    :param ipv6_list: {"minLength": 1, "maxLength": 63, "type": "string", "description": "IP-list of IPv6 remote clients (IP-list name)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "remote"
        self.DeviceProxy = ""
        self.ipv4_list = ""
        self.ipv6_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Attribute(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vendor: {"description": "RADIUS vendor attribute information (RADIUS vendor ID)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param name: {"minLength": 1, "maxLength": 15, "type": "string", "description": "Customized attribute name", "format": "string"}
    :param number: {"description": "RADIUS attribute number", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param value: {"enum": ["hexadecimal"], "type": "string", "description": "'hexadecimal': Type of attribute value is hexadecimal; ", "format": "enum"}
    :param custom_vendor: {"description": "RADIUS vendor attribute information (RADIUS vendor ID)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param custom_number: {"description": "RADIUS attribute number", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param attribute_value: {"enum": ["inside-ip", "inside-ipv6", "imei", "imsi", "msisdn", "custom1", "custom2", "custom3"], "type": "string", "description": "'inside-ip': Inside IP address; 'inside-ipv6': Inside IPv6 address; 'imei': International Mobile Equipment Identity (IMEI); 'imsi': International Mobile Subscriber Identity (IMSI); 'msisdn': Mobile Subscriber Integrated Services Digital Network-Number (MSISDN); 'custom1': Customized attribute 1; 'custom2': Customized attribute 2; 'custom3': Customized attribute 3; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "attribute"
        self.DeviceProxy = ""
        self.vendor = ""
        self.name = ""
        self.number = ""
        self.value = ""
        self.custom_vendor = ""
        self.custom_number = ""
        self.attribute_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Server(A10BaseClass):
    
    """Class Description::
    Configure system as a RADIUS server.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param vrid: {"description": "Join a VRRP-A failover group", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param secret: {"default": 0, "optional": true, "type": "number", "description": "Configure shared secret", "format": "flag"}
    :param attribute: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"vendor": {"description": "RADIUS vendor attribute information (RADIUS vendor ID)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "name": {"minLength": 1, "maxLength": 15, "type": "string", "description": "Customized attribute name", "format": "string"}, "number": {"description": "RADIUS attribute number", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "value": {"enum": ["hexadecimal"], "type": "string", "description": "'hexadecimal': Type of attribute value is hexadecimal; ", "format": "enum"}, "custom-vendor": {"description": "RADIUS vendor attribute information (RADIUS vendor ID)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "custom-number": {"description": "RADIUS attribute number", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "attribute-value": {"enum": ["inside-ip", "inside-ipv6", "imei", "imsi", "msisdn", "custom1", "custom2", "custom3"], "type": "string", "description": "'inside-ip': Inside IP address; 'inside-ipv6': Inside IPv6 address; 'imei': International Mobile Equipment Identity (IMEI); 'imsi': International Mobile Subscriber Identity (IMSI); 'msisdn': Mobile Subscriber Integrated Services Digital Network-Number (MSISDN); 'custom1': Customized attribute 1; 'custom2': Customized attribute 2; 'custom3': Customized attribute 3; ", "format": "enum"}, "optional": true}}]}
    :param listen_port: {"description": "Configure the listen port of RADIUS server (Port number)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1024, "optional": true}
    :param secret_string: {"description": "The RADIUS secret", "format": "password", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/radius/server`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "server"
        self.a10_url="/axapi/v3/cgnv6/lsn/radius/server"
        self.DeviceProxy = ""
        self.remote = {}
        self.encrypted = ""
        self.vrid = ""
        self.secret = ""
        self.attribute = []
        self.listen_port = ""
        self.secret_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param truncated_gre_packet: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param smp_session_creation_failure: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param mismatched_pns_call_id: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param mismatched_pac_call_id: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param current_gre_sessions: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param no_matching_gre_session: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param truncated_pac_message: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param truncated_pns_message: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param unknown_gre_version: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param current_smp_sessions: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param retransmitted_pns_message: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param retransmitted_pac_message: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.truncated_gre_packet = ""
        self.smp_session_creation_failure = ""
        self.mismatched_pns_call_id = ""
        self.mismatched_pac_call_id = ""
        self.current_gre_sessions = ""
        self.no_matching_gre_session = ""
        self.truncated_pac_message = ""
        self.truncated_pns_message = ""
        self.unknown_gre_version = ""
        self.current_smp_sessions = ""
        self.retransmitted_pns_message = ""
        self.retransmitted_pac_message = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Pptp(A10BaseClass):
    
    """Class Description::
    Statistics for the object pptp.

    Class pptp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/alg/pptp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "pptp"
        self.a10_url="/axapi/v3/ip/nat/alg/pptp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv6PrefixConfig(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_prefix_to: {"type": "string", "description": "IPv6 Prefix Range End", "format": "ipv6-address-plen"}
    :param count: {"type": "number", "description": "Number of IPv6 prefixes", "format": "number"}
    :param ipv6_addr_prefix: {"type": "string", "description": "IPv6 Prefix Range Start / IPv6 Prefix", "format": "ipv6-address-plen"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-prefix-config"
        self.DeviceProxy = ""
        self.ipv6_prefix_to = ""
        self.count = ""
        self.ipv6_addr_prefix = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6Config(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_end_addr: {"type": "string", "description": "IPv6 Range End Address", "format": "ipv6-address"}
    :param ipv6_start_addr: {"type": "string", "description": "IPv6 Range Start Address / IPv6 Address", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-config"
        self.DeviceProxy = ""
        self.ipv6_end_addr = ""
        self.ipv6_start_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4Config(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv4_start_addr: {"type": "string", "description": "IPv4 Range Start Address / IPv4 Address", "format": "ipv4-address"}
    :param ipv4_end_addr: {"type": "string", "description": "IPv4 Range End Address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv4-config"
        self.DeviceProxy = ""
        self.ipv4_start_addr = ""
        self.ipv4_end_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpList(A10BaseClass):
    
    """Class Description::
    Configure ip list.

    Class ip-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6_prefix_config: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-prefix-to": {"type": "string", "description": "IPv6 Prefix Range End", "format": "ipv6-address-plen"}, "count": {"type": "number", "description": "Number of IPv6 prefixes", "format": "number"}, "optional": true, "ipv6-addr-prefix": {"type": "string", "description": "IPv6 Prefix Range Start / IPv6 Prefix", "format": "ipv6-address-plen"}}}]}
    :param name: {"description": "Specify name of the ip list", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param ipv6_config: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-end-addr": {"type": "string", "description": "IPv6 Range End Address", "format": "ipv6-address"}, "optional": true, "ipv6-start-addr": {"type": "string", "description": "IPv6 Range Start Address / IPv6 Address", "format": "ipv6-address"}}}]}
    :param ipv4_config: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-start-addr": {"type": "string", "description": "IPv4 Range Start Address / IPv4 Address", "format": "ipv4-address"}, "ipv4-end-addr": {"type": "string", "description": "IPv4 Range End Address", "format": "ipv4-address"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip-list/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ip-list"
        self.a10_url="/axapi/v3/ip-list/{name}"
        self.DeviceProxy = ""
        self.ipv6_prefix_config = []
        self.name = ""
        self.ipv6_config = []
        self.ipv4_config = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EqualsList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param equals: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string equals another string", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "equals-list"
        self.DeviceProxy = ""
        self.equals = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ContainsList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param contains: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string contains another string", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "contains-list"
        self.DeviceProxy = ""
        self.contains = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EndsWithList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ends_with: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string ends with another string", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ends-with-list"
        self.DeviceProxy = ""
        self.ends_with = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServerNameList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param server_name: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Server name indication in Client hello extension (Server name String)", "format": "string"}
    :param server_key: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Server Private Key associated to SNI (Server Private Key Name)", "format": "string"}
    :param server_passphrase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "help Password Phrase", "format": "password"}
    :param server_encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param server_cert: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Server Certificate associated to SNI (Server Certificate Name)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "server-name-list"
        self.DeviceProxy = ""
        self.server_name = ""
        self.server_key = ""
        self.server_passphrase = ""
        self.server_encrypted = ""
        self.server_cert = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CaCerts(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ca_cert: {"minLength": 1, "maxLength": 255, "type": "string", "description": "CA Certificate (CA Certificate Name)", "format": "string"}
    :param client_ocsp: {"default": 0, "type": "number", "description": "Specify ocsp authentication server(s) for client certificate verification", "format": "flag"}
    :param client_ocsp_sg: {"description": "Specify service-group (Service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}
    :param client_ocsp_srvr: {"description": "Specify authentication server", "format": "string-rlx", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ocsp"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ca-certs"
        self.DeviceProxy = ""
        self.ca_cert = ""
        self.client_ocsp = ""
        self.client_ocsp_sg = ""
        self.client_ocsp_srvr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CipherWithoutPrioList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cipher_wo_prio: {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cipher-without-prio-list"
        self.DeviceProxy = ""
        self.cipher_wo_prio = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class StartsWithList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param starts_with: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string starts with another string", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "starts-with-list"
        self.DeviceProxy = ""
        self.starts_with = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClientSsl(A10BaseClass):
    
    """Class Description::
    Client SSL Template.

    Class client-ssl supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param chain_cert: {"description": "Chain Certificate (Chain Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param session_cache_timeout: {"description": "Session Cache Timeout (Timeout value, in seconds)", "format": "number", "type": "number", "maximum": 604800, "minimum": 0, "optional": true}
    :param ocspst_sg: {"description": "Specify authentication service group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "ocspst-srvr", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}
    :param auth_username: {"description": "Specify the Username Field in the Client Certificate(If multi-fields are specificed, prior one has higher priority)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param authorization: {"default": 0, "optional": true, "type": "number", "description": "Specify LDAP server for client SSL authorizaiton", "format": "flag"}
    :param ocspst_sg_hours: {"description": "Specify update period, in hours", "format": "number", "optional": true, "not-list": ["ocspst-sg-days", "ocspst-sg-minutes"], "maximum": 44640, "minimum": 1, "type": "number"}
    :param ocspst_sg_days: {"description": "Specify update period, in days", "format": "number", "optional": true, "not-list": ["ocspst-sg-hours", "ocspst-sg-minutes"], "maximum": 31, "minimum": 1, "type": "number"}
    :param ldap_search_filter: {"description": "Specify LDAP search filter", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param authen_name: {"description": "Specify authorization LDAP server name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "auth-sg", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap"}
    :param ocsp_stapling: {"default": 0, "optional": true, "type": "number", "description": "Config OCSP stapling support", "format": "flag"}
    :param forward_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param ocspst_srvr: {"description": "Specify OCSP authentication server", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "ocspst-sg", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ocsp"}
    :param class_list_name: {"description": "Class List Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param forward_proxy_ca_cert: {"description": "CA Certificate for forward proxy (SSL forward proxy CA Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param ocspst_sg_timeout: {"description": "Specify retry timeout (Default is 30 mins)", "format": "number", "type": "number", "maximum": 44640, "minimum": 1, "optional": true}
    :param ssl_false_start_disable: {"default": 0, "optional": true, "type": "number", "description": "disable SSL False Start", "format": "flag"}
    :param key_passphrase: {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param template_cipher: {"description": "Cipher Template (Cipher Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param ocspst_srvr_minutes: {"description": "Specify update period, in minutes", "format": "number", "optional": true, "not-list": ["ocspst-srvr-days", "ocspst-srvr-hours"], "maximum": 60, "minimum": 1, "type": "number"}
    :param auth_sg: {"description": "Specify authorization LDAP service group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "authen-name", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}
    :param key_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param equals_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "equals": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string equals another string", "format": "string-rlx"}}}]}
    :param session_ticket_lifetime: {"optional": true, "type": "number", "description": "Session ticket lieftime in seconds from stateless session resumption (Lifetime value in seconds)", "format": "number"}
    :param forward_passphrase: {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param ldap_base_dn_from_cert: {"default": 0, "optional": true, "type": "number", "description": "Use Subject DN as LDAP search base DN", "format": "flag"}
    :param contains_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"contains": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string contains another string", "format": "string-rlx"}, "optional": true}}]}
    :param forward_proxy_ca_key: {"description": "CA Private Key for forward proxy (SSL forward proxy CA Key Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param ocspst_srvr_days: {"description": "Specify update period, in days", "format": "number", "optional": true, "not-list": ["ocspst-srvr-hours", "ocspst-srvr-minutes"], "maximum": 31, "minimum": 1, "type": "number"}
    :param session_cache_size: {"description": "Session Cache Size (Specify 0 to disable Session ID reuse.)", "format": "number", "type": "number", "maximum": 8000000, "minimum": 0, "optional": true}
    :param client_certificate: {"description": "'Ignore': Don't request client certificate; 'Require': Require client certificate; 'Request': Request client certificate; ", "format": "enum", "default": "Ignore", "type": "string", "enum": ["Ignore", "Require", "Request"], "optional": true}
    :param ends_with_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ends-with": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string ends with another string", "format": "string-rlx"}, "optional": true}}]}
    :param ocspst_ca_cert: {"description": "CA certificate", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param ocspst_ocsp: {"default": 0, "optional": true, "type": "number", "description": "Specify OCSP Authentication", "format": "flag"}
    :param forward_proxy_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable SSL forward proxy", "format": "flag"}
    :param key: {"description": "Server Private Key (Key Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param sslv2_bypass_service_group: {"description": "Service Group for Bypass SSLV2 (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param server_name_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"server-name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Server name indication in Client hello extension (Server name String)", "format": "string"}, "server-key": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Server Private Key associated to SNI (Server Private Key Name)", "format": "string"}, "server-passphrase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "help Password Phrase", "format": "password"}, "optional": true, "server-encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}, "server-cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Server Certificate associated to SNI (Server Certificate Name)", "format": "string"}}}]}
    :param auth_sg_filter: {"description": "Specify LDAP search filter", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param ca_certs: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ca-cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "CA Certificate (CA Certificate Name)", "format": "string"}, "client-ocsp": {"default": 0, "type": "number", "description": "Specify ocsp authentication server(s) for client certificate verification", "format": "flag"}, "client-ocsp-sg": {"description": "Specify service-group (Service group name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "optional": true, "client-ocsp-srvr": {"description": "Specify authentication server", "format": "string-rlx", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ocsp"}}}]}
    :param disable_sslv3: {"default": 0, "optional": true, "type": "number", "description": "Reject Client requests for SSL version 3", "format": "flag"}
    :param ocspst_srvr_timeout: {"description": "Specify retry timeout (Default is 30 mins)", "format": "number", "type": "number", "maximum": 44640, "minimum": 1, "optional": true}
    :param name: {"description": "Client SSL Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param auth_sg_dn: {"default": 0, "optional": true, "type": "number", "description": "Use Subject DN as LDAP search base DN", "format": "flag"}
    :param ocspst_sg_period: {"default": 0, "optional": true, "type": "number", "description": "Specify certificate status update period (Default is 1 hour)", "format": "flag"}
    :param ocspst_srvr_hours: {"description": "Specify update period, in hours", "format": "number", "optional": true, "not-list": ["ocspst-srvr-days", "ocspst-srvr-minutes"], "maximum": 44640, "minimum": 1, "type": "number"}
    :param cert: {"description": "Server Certificate (Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param ocspst_srvr_period: {"default": 0, "optional": true, "type": "number", "description": "Specify certificate status update period (Default is 1 hour)", "format": "flag"}
    :param crl: {"description": "Certificate Revocation Lists (Certificate Revocation Lists file name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param case_insensitive: {"default": 0, "optional": true, "type": "number", "description": "Case insensitive forward proxy bypass", "format": "flag"}
    :param cipher_without_prio_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cipher-wo-prio": {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}, "optional": true}}]}
    :param ocspst_sg_minutes: {"description": "Specify update period, in minutes", "format": "number", "optional": true, "not-list": ["ocspst-sg-days", "ocspst-sg-hours"], "maximum": 60, "minimum": 1, "type": "number"}
    :param starts_with_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"starts-with": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Forward proxy bypass if SNI string starts with another string", "format": "string-rlx"}, "optional": true}}]}
    :param close_notify: {"default": 0, "optional": true, "type": "number", "description": "Send close notification when terminate connection", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/client-ssl/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "client-ssl"
        self.a10_url="/axapi/v3/slb/template/client-ssl/{name}"
        self.DeviceProxy = ""
        self.chain_cert = ""
        self.session_cache_timeout = ""
        self.ocspst_sg = ""
        self.auth_username = ""
        self.authorization = ""
        self.ocspst_sg_hours = ""
        self.ocspst_sg_days = ""
        self.ldap_search_filter = ""
        self.authen_name = ""
        self.ocsp_stapling = ""
        self.forward_encrypted = ""
        self.ocspst_srvr = ""
        self.class_list_name = ""
        self.forward_proxy_ca_cert = ""
        self.ocspst_sg_timeout = ""
        self.ssl_false_start_disable = ""
        self.key_passphrase = ""
        self.template_cipher = ""
        self.ocspst_srvr_minutes = ""
        self.auth_sg = ""
        self.key_encrypted = ""
        self.equals_list = []
        self.session_ticket_lifetime = ""
        self.forward_passphrase = ""
        self.ldap_base_dn_from_cert = ""
        self.contains_list = []
        self.forward_proxy_ca_key = ""
        self.ocspst_srvr_days = ""
        self.session_cache_size = ""
        self.client_certificate = ""
        self.ends_with_list = []
        self.ocspst_ca_cert = ""
        self.ocspst_ocsp = ""
        self.forward_proxy_enable = ""
        self.key = ""
        self.sslv2_bypass_service_group = ""
        self.server_name_list = []
        self.auth_sg_filter = ""
        self.ca_certs = []
        self.disable_sslv3 = ""
        self.ocspst_srvr_timeout = ""
        self.name = ""
        self.auth_sg_dn = ""
        self.ocspst_sg_period = ""
        self.ocspst_srvr_hours = ""
        self.cert = ""
        self.ocspst_srvr_period = ""
        self.crl = ""
        self.case_insensitive = ""
        self.cipher_without_prio_list = []
        self.ocspst_sg_minutes = ""
        self.starts_with_list = []
        self.close_notify = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Buffer(A10BaseClass):
    
    """Class Description::
    Logging via email buffering settings.

    Class buffer supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param number: {"description": "Number of log messages that can be buffered (Number of log messages that can be buffered, default 50)", "format": "number", "default": 50, "optional": true, "maximum": 256, "minimum": 16, "type": "number"}
    :param time: {"description": "Number of minutes a log message can stay in buffer (Number of minutes a log message can stay in buffer, default 10)", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 10, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/email/buffer`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "buffer"
        self.a10_url="/axapi/v3/logging/email/buffer"
        self.DeviceProxy = ""
        self.number = ""
        self.time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SslCards(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param unknown_ssl_cards: {"type": "number", "format": "number"}
    :param hsm: {"type": "number", "format": "number"}
    :param ssl_devices: {"type": "number", "format": "number"}
    :param nitroxpx: {"type": "number", "format": "number"}
    :param nitrox3: {"type": "number", "format": "number"}
    :param nitrox2: {"type": "number", "format": "number"}
    :param nitrox1: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ssl-cards"
        self.DeviceProxy = ""
        self.unknown_ssl_cards = ""
        self.hsm = ""
        self.ssl_devices = ""
        self.nitroxpx = ""
        self.nitrox3 = ""
        self.nitrox2 = ""
        self.nitrox1 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CompressionCards(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param aha363: {"type": "number", "format": "number"}
    :param unknown_compression: {"type": "number", "format": "number"}
    :param gzip_devices: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "compression-cards"
        self.DeviceProxy = ""
        self.aha363 = ""
        self.unknown_compression = ""
        self.gzip_devices = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bios_version: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param fpga_summary: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param cpu_cores: {"type": "number", "format": "number"}
    :param l23_asic: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param bios_release_date: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param ipmi: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param storage: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param cpu_stepping: {"type": "number", "format": "number"}
    :param fpga_date: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param memory: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param platform_description: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param serial: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param cpu: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param ports: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.bios_version = ""
        self.fpga_summary = ""
        self.cpu_cores = ""
        self.l23_asic = ""
        self.bios_release_date = ""
        self.ipmi = ""
        self.storage = ""
        self.cpu_stepping = ""
        self.fpga_date = ""
        self.memory = ""
        self.platform_description = ""
        self.ssl_cards = {}
        self.serial = ""
        self.compression_cards = {}
        self.cpu = ""
        self.ports = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Hardware(A10BaseClass):
    
    """Class Description::
    Operational Status for the object hardware.

    Class hardware supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/hardware/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "hardware"
        self.a10_url="/axapi/v3/system/hardware/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Email(A10BaseClass):
    
    """Class Description::
    Set logging level which sent to email address.

    Class email supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param filter_list: {"minItems": 1, "items": {"type": "filter"}, "uniqueItems": true, "array": [{"required": ["filter-id"], "properties": {"filter-id": {"description": "Logging via email filter settings", "format": "number", "type": "number", "maximum": 8, "minimum": 1, "optional": false}, "trigger": {"default": 0, "optional": true, "type": "number", "description": "Trigger email, override buffer settings", "format": "flag"}, "expression": {"description": "Reverse Polish Notation, consists of level 0-7, module AFLEX/HMON/..., pattern log-content-pattern, and or/and/not", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 511, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/logging/email/filter/{filter-id}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/email`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "email"
        self.a10_url="/axapi/v3/logging/email"
        self.DeviceProxy = ""
        self.A10WW_buffer = {}
        self.filter_list = []
        self.level = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MessageDigestCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param md5_value: {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}
    :param message_digest_key: {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "message-digest-cfg"
        self.DeviceProxy = ""
        self.md5_value = ""
        self.message_digest_key = ""
        self.encrypted = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OspfIp(A10BaseClass):
    
    """Class Description::
    IP address configuration for Open Shortest Path First for IPv4 (OSPF).

    Class ospf-ip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dead_interval: {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param authentication_key: {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}
    :param mtu_ignore: {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}
    :param priority: {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}
    :param transmit_delay: {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param value: {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}
    :param hello_interval: {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param authentication: {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}
    :param cost: {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param database_filter: {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}
    :param ip_addr: {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}
    :param retransmit_interval: {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param message_digest_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}
    :param out: {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/trunk/{ifnum}/ip/ospf/ospf-ip/{ip_addr}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_addr"]

        self.b_key = "ospf-ip"
        self.a10_url="/axapi/v3/interface/trunk/{ifnum}/ip/ospf/ospf-ip/{ip_addr}"
        self.DeviceProxy = ""
        self.dead_interval = ""
        self.authentication_key = ""
        self.mtu_ignore = ""
        self.priority = ""
        self.transmit_delay = ""
        self.value = ""
        self.hello_interval = ""
        self.authentication = ""
        self.cost = ""
        self.database_filter = ""
        self.ip_addr = ""
        self.retransmit_interval = ""
        self.message_digest_cfg = []
        self.out = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acct_port: {"description": "Specify the RADIUS server's accounting port (default 1813)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param retransmit: {"description": "Specify the maximum times allowed for resending an request to the radius server (default 3)", "format": "number", "default": 3, "maximum": 5, "minimum": 0, "type": "number"}
    :param timeout: {"description": "Specify the maximum time allowed for waiting for a response from a radius server (default 3)", "format": "number", "default": 3, "maximum": 15, "minimum": 1, "type": "number"}
    :param auth_port: {"description": "Specify the RADIUS server's authentication port (default 1812)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-cfg"
        self.DeviceProxy = ""
        self.acct_port = ""
        self.retransmit = ""
        self.timeout = ""
        self.auth_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Secret(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param encrypted: {"type": "encrypted", "description": " Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param secret_value: {"minLength": 1, "maxLength": 128, "type": "string", "description": "The RADIUS server's secret", "format": "password"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "secret"
        self.DeviceProxy = ""
        self.port_cfg = {}
        self.encrypted = ""
        self.secret_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4(A10BaseClass):
    
    """Class Description::
    Specify the hostname of RADIUS server.

    Class ipv4 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv4_addr: {"optional": false, "type": "string", "description": "IPV4 address of RADIUS server", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/radius-server/host/ipv4/{ipv4_addr}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv4_addr"]

        self.b_key = "ipv4"
        self.a10_url="/axapi/v3/radius-server/host/ipv4/{ipv4_addr}"
        self.DeviceProxy = ""
        self.ipv4_addr = ""
        self.secret = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SourceIpAddress(A10BaseClass):
    
    """Class Description::
    IP Address of the local tunnel end point.

    Class source-ip-address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vni_list: {"minItems": 1, "items": {"type": "vni"}, "uniqueItems": true, "array": [{"required": ["segment"], "properties": {"lif": {"description": "Logical interface binding the Provider Partition to the User Partition (logical interface number)", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": true}, "partition": {"description": "Name of the Partition with the L2 segment being extended (Name of the User Partition with the L2 segment being extended)", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "segment": {"description": "Id of the segment that is being extended", "format": "number", "type": "number", "maximum": 16777215, "minimum": 1, "optional": false}, "gateway": {"default": 0, "optional": true, "type": "number", "description": "This is a Gateway segment id", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}/source-ip-address/vni/{segment}"}
    :param ip_address: {"optional": false, "type": "string", "description": "Source Tunnel End Point IPv4 address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/overlay-tunnel/vtep/{id}/source-ip-address`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "source-ip-address"
        self.a10_url="/axapi/v3/overlay-tunnel/vtep/{id}/source-ip-address"
        self.DeviceProxy = ""
        self.vni_list = []
        self.ip_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


